@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.6003';
+our $VERSION = '0.6004';
 
 use 5.024;
 use strictures 2;
@@ -219,7 +219,7 @@ sub set_channel ( $self, $channel = 9 ) {
 #pod   $d->set_volume;
 #pod   $d->set_volume($volume);
 #pod
-#pod Set the volume (L<Types::MIDI/Velocity>) to the given argument.
+#pod Set the volume (L<MIDI::Drummer::Tiny::Types::MIDI/Velocity>) to the given argument.
 #pod
 #pod If not given a B<volume> argument, this method mutes (sets to C<0>).
 #pod
@@ -1467,7 +1467,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.6003
+version 0.6004
 
 =head1 SYNOPSIS
 
@@ -1645,7 +1645,7 @@ different.
   $d->set_volume;
   $d->set_volume($volume);
 
-Set the volume (L<Types::MIDI/Velocity>) to the given argument.
+Set the volume (L<MIDI::Drummer::Tiny::Types::MIDI/Velocity>) to the given argument.
 
 If not given a B<volume> argument, this method mutes (sets to C<0>).
 
@@ -1953,7 +1953,7 @@ See L<MIDI::Util/play_fluidsynth> for more details.
 
 Any of these attributes may be changed when calling L</new>.
 Drumkit values must be a valid
-L<Types::MIDI/PercussionNote>,
+L<MIDI::Drummer::Tiny::Types::MIDI/PercussionNote>,
 while note duration values must be a valid
 L<MIDI::Drummer::Tiny/Duration>.
 
